/**
 * Redistribution and use of this software and associated documentation
 * ("Software"), with or without modification, are permitted provided
 * that the following conditions are met:
 *
 * 1. Redistributions of source code must retain copyright
 *    statements and notices.  Redistributions must also contain a
 *    copy of this document.
 *
 * 2. Redistributions in binary form must reproduce the
 *    above copyright notice, this list of conditions and the
 *    following disclaimer in the documentation and/or other
 *    materials provided with the distribution.
 *
 * 3. The name "Exolab" must not be used to endorse or promote
 *    products derived from this Software without prior written
 *    permission of Intalio, Inc.  For written permission,
 *    please contact info@exolab.org.
 *
 * 4. Products derived from this Software may not be called "Exolab"
 *    nor may "Exolab" appear in their names without prior written
 *    permission of Intalio, Inc. Exolab is a registered
 *    trademark of Intalio, Inc.
 *
 * 5. Due credit should be given to the Exolab Project
 *    (http://www.exolab.org/).
 *
 * THIS SOFTWARE IS PROVIDED BY INTALIO, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL
 * INTALIO, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * Copyright 2000 (C) Intalio, Inc. All Rights Reserved.
 *
 * $Id: ConsoleDialog.java 3633 2003-03-01 07:38:44Z kvisco $
 */

package org.exolab.adaptx.util;

/**
 * A simple utility class to handle command line dialogs
 *
 * @author <a href="mailto:kvisco@intalio.com">Keith Visco</a>
 * @version $Revision: 3633 $ $Date: 2003-03-01 02:38:44 -0500 (Sat, 01 Mar 2003) $
**/
public class ConsoleDialog {
    
    
    /**
     * Creates a new Console Dialog
    **/
    public ConsoleDialog () {
        super();
    } //-- ConsoleDialog
    
    /**
     * Presents a confirmation prompt with the given message
     * @param message, the confirmation prompt message to display
     * @return true if the user has selected a positive confirmation,
     * otherwise false
    **/
    public boolean confirm(String message) {

        try {
            while (true) {
                System.out.println();
                System.out.print(message);
                System.out.print( " (y|n|?) : ");

                int ch = System.in.read();

                //-- read eoln, or extra characters
                while (System.in.available() > 0) {
                    switch (System.in.read()) {
                        case '\n':
                        case '\r':
                            break;
                        default:
                            ch = '\0';
                    }
                }

                System.out.println();

                //-- check ch
                switch (ch) {
                    case 'y':
                        return true;
                    case 'n':
                        return false;
                    case '?':
                        System.out.println("y = yes, n = no");
                        break;
                    default:
                        System.out.print("invalid input, expecting ");
                        System.out.println("'y', 'n', or '?'.");
                        break;
                }
            }
        }
        catch (java.io.IOException ix) {
            System.out.println(ix);
        }
        return false;
    } //-- confirm
    
} //-- ConsoleDialog
