/*
 * (C) Copyright Keith Visco 1999  All rights reserved.
 *
 * The contents of this file are released under an Open Source 
 * Definition (OSD) compliant license; you may not use this file 
 * execpt in compliance with the license. Please see license.txt, 
 * distributed with this file. You may also obtain a copy of the
 * license at http://www.kvisco.com/xslp/license.txt
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * The Copyright owner will not be liable for any damages suffered by
 * you as a result of using the Program. In no event will the Copyright
 * owner be liable for any special, indirect or consequential damages or
 * lost profits even if the Copyright owner has been advised of the
 * possibility of their occurrence.
 *
 * $Id: PredicateExprImpl.java 3737 2003-05-13 07:59:57Z kvisco $
 */


package org.exolab.adaptx.xpath.engine;


import org.exolab.adaptx.xpath.XPathNode;
import org.exolab.adaptx.xpath.XPathResult;
import org.exolab.adaptx.xpath.XPathContext;
import org.exolab.adaptx.xpath.XPathExpression;
import org.exolab.adaptx.xpath.BooleanResult;
import org.exolab.adaptx.xpath.XPathException;
import org.exolab.adaptx.xpath.NodeSet;
import org.exolab.adaptx.xpath.expressions.PredicateExpr;

/**
 * This class represents an XPath predicate expression.
 *
 * @author <a href="mailto:kvisco@intalio.com">Keith Visco</a>
 * @version $Revision: 3737 $ $Date: 2003-05-13 03:59:57 -0400 (Tue, 13 May 2003) $
 */
class PredicateExprImpl extends PredicateExpr
{

    
    private XPathExpression _expr;


    private PredicateExprImpl _next = null;


    /**
     * Creates a new PredicateExpr using the given XPathExpression
     * as the underlying expression which determines true or false.
     */
    public PredicateExprImpl(XPathExpression expr)
        throws XPathException
    {
        if ( expr == null )
            throw new XPathException( "Argument expr is null" );
        _expr = expr;
    } //-- PredicateExpr

    
    /**
     * Evaluates the expression and returns the XPath result.
     *
     * @param context The XPathContext to use during evaluation.
     * @return The XPathResult (not null).
     * @exception XPathException if an error occured while 
     * evaluating this expression.
    **/
    public XPathResult evaluate(XPathContext context)
        throws XPathException
    {
        if ( _expr == null )
            return BooleanResult.FALSE;
        return _expr.evaluate( context );
    } //-- evaluate


    /**
     * Returns the actual XPathExpression for this predicate
     *
     * @return the XPathExpression for this predicate
     */
    public XPathExpression getExpression() {
        return _expr;
    }
    
    /**
     * Returns the next PredicateExpr for this PredicateExpr
     *
     * @returns the next PredicateExpr in this PredicateExpr
     */
    public PredicateExpr getNext()
    {
        return _next;
    } //-- getNext

    
    /**
     * Returns true if there are more predicate expressions
     * 
     * @return true if there are more predicate expressions
     */
    public boolean hasNext()
    {
        return _next != null;
    }

        
    public void setNext( PredicateExprImpl expr )
        throws XPathException
    {
        if ( expr== null )
            throw new XPathException( "Argument expr is null" );
        this._next = expr;
    }

    
    public String toString()
    {
        return toString( null );
    }

    
    private String toString( StringBuffer sb )
    {
        if ( sb == null )
            sb = new StringBuffer();
        if ( _expr != null ) {
            sb.append( '[' );
            sb.append( _expr.toString() );
            sb.append( ']' );
            if ( _next != null )
                _next.toString(sb);
        }
        return sb.toString();
    } //-- toString

    
} //-- Predicate
